@@ -745,6 +745,7 @@ as_app_validate_icons (AsApp *app, AsAppValidateHelper *helper)
 static void
 as_app_validate_screenshots (AsApp *app, AsAppValidateHelper *helper)
 {
+	AsFormat *format;
 	AsScreenshot *ss;
 	GPtrArray *screenshots;
 	gboolean screenshot_has_default = FALSE;
@@ -765,11 +766,12 @@ as_app_validate_screenshots (AsApp *app, AsAppValidateHelper *helper)
 		number_screenshots_min = 0;
 
 	/* metainfo and inf do not require any screenshots */
-	if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO)
+	format = as_app_get_format_default (app);
+	if (as_format_get_kind (format) == AS_FORMAT_KIND_METAINFO)
 		number_screenshots_min = 0;
 
 	/* only for AppData and AppStream */
-	if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_DESKTOP)
+	if (as_format_get_kind (format) == AS_FORMAT_KIND_DESKTOP)
 		return;
 
 	screenshots = as_app_get_screenshots (app);
@@ -840,6 +842,13 @@ as_app_validate_release (AsApp *app,
 				     "<release> timestamp should be a UNIX time");
 	}
 
+	/* check the timestamp is not in the future */
+	if (timestamp > (guint64) g_get_real_time () / G_USEC_PER_SEC) {
+		ai_app_validate_add (helper,
+				     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
+				     "<release> timestamp is in the future");
+	}
+
 	/* for firmware, check urgency */
 	if (as_app_get_kind (app) == AS_APP_KIND_FIRMWARE &&
 	    as_release_get_urgency (release) == AS_URGENCY_KIND_UNKNOWN) {
@@ -872,21 +881,62 @@ as_app_validate_release (AsApp *app,
 static gboolean
 as_app_validate_releases (AsApp *app, AsAppValidateHelper *helper, GError **error)
 {
-	AsRelease *release;
 	GPtrArray *releases;
-	guint i;
+	AsFormat *format;
 
 	/* only for AppData */
-	if (as_app_get_source_kind (app) != AS_APP_SOURCE_KIND_APPDATA &&
-	    as_app_get_source_kind (app) != AS_APP_SOURCE_KIND_METAINFO)
+	format = as_app_get_format_default (app);
+	if (as_format_get_kind (format) != AS_FORMAT_KIND_APPDATA &&
+	    as_format_get_kind (format) != AS_FORMAT_KIND_METAINFO)
 		return TRUE;
 
 	releases = as_app_get_releases (app);
-	for (i = 0; i < releases->len; i++) {
-		release = g_ptr_array_index (releases, i);
+	for (guint i = 0; i < releases->len; i++) {
+		AsRelease *release = g_ptr_array_index (releases, i);
 		if (!as_app_validate_release (app, release, helper, error))
 			return FALSE;
 	}
+
+	/* check the version numbers go down each time */
+	if (releases->len > 1) {
+		AsRelease *release_old = g_ptr_array_index (releases, 0);
+		for (guint i = 1; i < releases->len; i++) {
+			AsRelease *release = g_ptr_array_index (releases, i);
+			const gchar *version = as_release_get_version (release);
+			const gchar *version_old = as_release_get_version (release_old);
+			if (version == NULL || version_old == NULL)
+				continue;
+			if (as_utils_vercmp (version, version_old) > 0) {
+				ai_app_validate_add (helper,
+						     AS_PROBLEM_KIND_TAG_INVALID,
+						     "<release> versions are not in order "
+						     "[%s before %s]",
+						     version_old, version);
+			}
+			release_old = release;
+		}
+	}
+
+	/* check the timestamps go down each time */
+	if (releases->len > 1) {
+		AsRelease *release_old = g_ptr_array_index (releases, 0);
+		for (guint i = 1; i < releases->len; i++) {
+			AsRelease *release = g_ptr_array_index (releases, i);
+			guint64 timestamp = as_release_get_timestamp (release);
+			guint64 timestamp_old = as_release_get_timestamp (release_old);
+			if (timestamp == 0 || timestamp_old == 0)
+				continue;
+			if (timestamp > timestamp_old) {
+				ai_app_validate_add (helper,
+						     AS_PROBLEM_KIND_TAG_INVALID,
+						     "<release> timestamps are not in order "
+						     "[%" G_GUINT64_FORMAT " before %" G_GUINT64_FORMAT "]",
+						     timestamp_old, timestamp);
+			}
+			release_old = release;
+		}
+	}
+
 	return TRUE;
 }
 
@@ -1018,6 +1068,7 @@ GPtrArray *
 as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 {
 	AsAppProblems problems;
+	AsFormat *format;
 	GError *error_local = NULL;
 	GHashTable *urls;
 	GList *l;
@@ -1052,6 +1103,16 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 	g_autoptr(GList) keys = NULL;
 	g_autoptr(AsAppValidateHelper) helper = g_new0 (AsAppValidateHelper, 1);
 
+	/* has to be set */
+	format = as_app_get_format_default (app);
+	if (format == NULL) {
+		g_set_error_literal (error,
+				     AS_APP_ERROR,
+				     AS_APP_ERROR_FAILED,
+				     "cannot validate without at least one format");
+		return NULL;
+	}
+
 	/* relax the requirements a bit */
 	if ((flags & AS_APP_VALIDATE_FLAG_RELAX) > 0) {
 		length_name_max = 100;
@@ -1064,8 +1125,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 		number_para_min = 1;
 		require_sentence_case = FALSE;
 		require_translation = FALSE;
-		switch (as_app_get_source_kind (app)) {
-		case AS_APP_SOURCE_KIND_METAINFO:
+		switch (as_format_get_kind (format)) {
+		case AS_FORMAT_KIND_METAINFO:
+		case AS_FORMAT_KIND_APPDATA:
 			require_name = FALSE;
 			break;
 		default:
@@ -1084,9 +1146,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 	}
 
 	/* addons don't need such a long description */
-	switch (as_app_get_source_kind (app)) {
-	case AS_APP_SOURCE_KIND_METAINFO:
-	case AS_APP_SOURCE_KIND_APPDATA:
+	switch (as_format_get_kind (format)) {
+	case AS_FORMAT_KIND_METAINFO:
+	case AS_FORMAT_KIND_APPDATA:
 		number_para_min = 1;
 		break;
 	default:
@@ -1164,9 +1226,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 		}
 	}
 	if (license == NULL) {
-		switch (as_app_get_source_kind (app)) {
-		case AS_APP_SOURCE_KIND_APPDATA:
-		case AS_APP_SOURCE_KIND_METAINFO:
+		switch (as_format_get_kind (format)) {
+		case AS_FORMAT_KIND_APPDATA:
+		case AS_FORMAT_KIND_METAINFO:
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_MISSING,
 					     "<metadata_license> is not present");
@@ -1191,9 +1253,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 		}
 	}
 	if (require_project_license && license == NULL) {
-		switch (as_app_get_source_kind (app)) {
-		case AS_APP_SOURCE_KIND_APPDATA:
-		case AS_APP_SOURCE_KIND_METAINFO:
+		switch (as_format_get_kind (format)) {
+		case AS_FORMAT_KIND_APPDATA:
+		case AS_FORMAT_KIND_METAINFO:
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_MISSING,
 					     "<project_license> is not present");
@@ -1205,7 +1267,7 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* translation */
 	if (require_translation &&
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA &&
+	    as_format_get_kind (format) == AS_FORMAT_KIND_APPDATA &&
 	    as_app_get_translations (app)->len == 0) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_TAG_MISSING,
@@ -1214,7 +1276,7 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* pkgname */
 	if (as_app_get_pkgname_default (app) != NULL &&
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO) {
+	    as_format_get_kind (format) == AS_FORMAT_KIND_METAINFO) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_TAG_INVALID,
 				     "<pkgname> not allowed in metainfo");
@@ -1222,7 +1284,7 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* appdata */
 	if (as_app_get_icon_default (app) != NULL &&
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA &&
+	    as_format_get_kind (format) == AS_FORMAT_KIND_APPDATA &&
 	    as_app_get_kind (app) == AS_APP_KIND_DESKTOP) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_TAG_INVALID,
@@ -1232,7 +1294,7 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 	/* extends */
 	if (as_app_get_extends(app)->len == 0 &&
 	    as_app_get_kind (app) == AS_APP_KIND_ADDON &&
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO) {
+	    as_format_get_kind (format) == AS_FORMAT_KIND_METAINFO) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_TAG_MISSING,
 				     "<extends> is not present");
@@ -1253,9 +1315,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 				     update_contact);
 	}
 	if (require_contactdetails && update_contact == NULL) {
-		switch (as_app_get_source_kind (app)) {
-		case AS_APP_SOURCE_KIND_APPDATA:
-		case AS_APP_SOURCE_KIND_METAINFO:
+		switch (as_format_get_kind (format)) {
+		case AS_FORMAT_KIND_APPDATA:
+		case AS_FORMAT_KIND_METAINFO:
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_MISSING,
 					     "<update_contact> is not present");
@@ -1267,8 +1329,8 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* only found for files */
 	problems = as_app_get_problems (app);
-	if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA ||
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO) {
+	if (as_format_get_kind (format) == AS_FORMAT_KIND_APPDATA ||
+	    as_format_get_kind (format) == AS_FORMAT_KIND_METAINFO) {
 		if ((problems & AS_APP_PROBLEM_NO_XML_HEADER) > 0) {
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_MARKUP_INVALID,
@@ -1317,6 +1379,13 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 				     "<keyword> invalid contents");
 	}
 
+	/* releases all have to have unique versions */
+	if (problems & AS_APP_PROBLEM_DUPLICATE_RELEASE) {
+		ai_app_validate_add (helper,
+				     AS_PROBLEM_KIND_TAG_INVALID,
+				     "<release> version was duplicated");
+	}
+
 	/* check for things that have to exist */
 	if (as_app_get_id (app) == NULL) {
 		ai_app_validate_add (helper,
@@ -1525,9 +1594,9 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* require homepage */
 	if (require_url && as_app_get_url_item (app, AS_URL_KIND_HOMEPAGE) == NULL) {
-		switch (as_app_get_source_kind (app)) {
-		case AS_APP_SOURCE_KIND_APPDATA:
-		case AS_APP_SOURCE_KIND_METAINFO:
+		switch (as_format_get_kind (format)) {
+		case AS_FORMAT_KIND_APPDATA:
+		case AS_FORMAT_KIND_METAINFO:
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_MISSING,
 					     "<url> is not present");
